SystemOrganization addCategory: #'OCMSTest-Kernel'!

TestCase subclass: #UserManagerTest
	instanceVariableNames: 'userManager'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'OCMSTest-Kernel'!

!UserManagerTest methodsFor: 'setUp' stamp: 'oda 5/1/2013 23:21'!
setUp
	userManager := UserManager new.! !

!UserManagerTest methodsFor: 'accessing' stamp: 'oda 5/2/2013 01:02'!
testBlockUser
	| anUser |
	anUser := User new login: 'user'.
	userManager includeUser: anUser.
	self assert: (userManager userWithLogin: 'user') isEnabled.
	
	userManager blockUserWithLogin: 'user'.
	self deny: (userManager userWithLogin: 'user') isEnabled.
	! !

!UserManagerTest methodsFor: 'accessing' stamp: 'oda 5/2/2013 00:12'!
testIncludeUser
	self shouldnt: [
		userManager includeUserWithLogin: 'user'
					withPassword: 'test'
					withEmail: 'test@test.com'
					withName: 'User'
					isAdmin: false
		] raise: Error.
	
	self should: [
		userManager includeUserWithLogin: 'user'
					withPassword: 'test'
					withEmail: 'test@test.com'
					withName: 'User'
					isAdmin: false
		] raise: Error.
	
	self should: [
		userManager includeUserWithLogin: 'user'
					withPassword: 'test2'
					withEmail: 'test2@test2.com'
					withName: 'User2'
					isAdmin: false
		] raise: Error.! !

!UserManagerTest methodsFor: 'initialize-release' stamp: 'oda 5/1/2013 23:51'!
testInitialize
	self assert: userManager user isEmpty.! !

!UserManagerTest methodsFor: 'accessing' stamp: 'oda 5/2/2013 00:20'!
testRemoveUser
	| user1 user2  anotherUser2 |
	user1 := User new login: 'user1'.
	user2 := User new login: 'user2'.
	anotherUser2 := User new login: 'user2'.
	
	userManager includeUser: user1.
	self shouldnt: [userManager removeUser: user1] raise: Error.
	self should: [userManager removeUser: user2] raise: Error.
	self should: [userManager removeUser: user1] raise: Error.
		
	userManager includeUser: user2.
	self shouldnt: [userManager removeUser: anotherUser2] raise: Error.
	
	userManager includeUser: user2.
	self shouldnt: [userManager removeUserWithLogin: user2 login] raise: Error.
	
! !

!UserManagerTest methodsFor: 'accessing' stamp: 'oda 5/2/2013 00:45'!
testUpdateUser
	| anUser |
	anUser := User new login: 'user';
						password: 'test';
						email: 'test@test.com';
						name: 'User'.
						
	userManager includeUser: anUser.
	
	self should: [userManager updateUser: (User new login: 'dontExists')] raise: Error.
	self shouldnt: [userManager updateUserWithLogin: anUser login
								withPassword: 'anotherPassword'
								withEmail: 'anotherEmail'
								withName: 'anotherName'
								isAdmin: false
		] raise: Error.

	anUser := userManager user array at:(userManager user scanFor: (User new login: anUser login)).
	self assert: anUser password = 'anotherPassword'.
	self assert: anUser email = 'anotherEmail'.
	self assert: anUser name = 'anotherName'.! !

!UserManagerTest methodsFor: 'accessing' stamp: 'oda 5/1/2013 23:58'!
testUser
	| anUser |
	anUser := userManager includeUserWithLogin: 'user' 
							withPassword: 'test'
							withEmail: 'test@test.com'
							withName: 'User'
							isAdmin: false.
	self assert: (userManager user includes: anUser).! !

!UserManagerTest methodsFor: 'accessing' stamp: 'oda 5/2/2013 01:07'!
testUserWithLogin
	| anUser anotherUser |
	anUser := User new login: 'user';
						password: 'test';
						email: 'test@test.com';
						name: 'User'.
	userManager includeUser: anUser.
	self should: [userManager userWithLogin: 'doesntExist'] raise: Error.
	
	self shouldnt: [anotherUser := userManager userWithLogin: anUser login] raise: Error.
	self assert: anotherUser == anUser.! !

TestCase subclass: #UserTest
	instanceVariableNames: 'admin professor student'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'OCMSTest-Kernel'!

!UserTest methodsFor: 'setUp' stamp: 'oda 5/1/2013 21:07'!
setUp
	"Setups an admin, a professor and a student"
	admin := User new isAdmin: true;
						name: 'Admin';
						email: 'admin@test.com';
						login: 'admin';
						password: 'admin'.
	
	professor := User new name: 'Professor';
						email: 'professor@test.com';
						login: 'professor';
						password: 'professor'.
							
	student := User new name: 'Student';
						email: 'student@test.com';
						login: 'student';
						password: 'student'.! !

!UserTest methodsFor: 'basic' stamp: 'oda 5/1/2013 19:48'!
testEquals
	"Asserts deep equality."
	self assert: admin = admin.
	self assert: admin = (User new login: (admin login)).
	self deny: admin = student.
	self deny: student = professor.! !

!UserTest methodsFor: 'accessing' stamp: 'oda 5/1/2013 23:50'!
testIncludeCourse
	"Tests consistency upon including a user role within a course"
	| aCourse |
	aCourse := Course new.
	
	self should: [student includeCourse: aCourse withRole: 'anything'] raise: Error.
	self should: [student includeCourse: 'anything' withRole: UserType student] raise: Error.
	
	self shouldnt: [student includeCourse: aCourse withRole: UserType student] raise: Error.
	self assert: (student course includes: aCourse).
	self shouldnt: [professor includeCourse: aCourse withRole: UserType professor] raise: Error.
	self shouldnt: [professor includeCourse: aCourse withRole: UserType student] raise: Error.! !

!UserTest methodsFor: 'initialize-release' stamp: 'oda 5/1/2013 23:50'!
testInitialize
	"Asserts initialization after instance creation"
	self assert: admin isAdmin.
	self assert: admin isEnabled.
	self assert: admin course isEmpty.
	
	self deny: professor isAdmin.
	self assert: professor isEnabled.
	self assert: professor course isEmpty.
! !

!UserTest methodsFor: 'accessing' stamp: 'oda 5/1/2013 21:14'!
testRoleAtCourse
	"Tests accessing an user role within a course"
	| aCourse anotherCourse |
	aCourse := Course new.
	anotherCourse := Course new.
	
	student includeCourse: aCourse withRole: UserType student.
	self shouldnt: [student roleAtCourse: aCourse] raise: Error.
	self assert: (student roleAtCourse: aCourse) = UserType student.
	
	self should: [student roleAtCourse: 'aCourse'] raise: Error.
	self should: [student roleAtCourse: anotherCourse] raise: Error. 
	
	! !

TestCase subclass: #UserTypeTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'OCMSTest-Kernel'!

!UserTypeTest methodsFor: 'instance creation' stamp: 'oda 5/1/2013 18:31'!
testNew
	self should: [UserType new] raise: Error.! !

!UserTypeTest methodsFor: 'accessing' stamp: 'oda 5/1/2013 20:18'!
testProfessor
	self assert: (UserType UserTypeList includes: UserType professor).! !

!UserTypeTest methodsFor: 'accessing' stamp: 'oda 5/1/2013 20:18'!
testStudent
	self assert: (UserType UserTypeList includes: UserType student).! !
